ottla.postgresql


brin-index-templateclj

source

btree-key-index-templateclj

source

column-typesclj

source

commit-modesclj

source

commit-offset!clj

(commit-offset! {:keys [conn schema]} {:keys [topic group]} cursor)
source

connect-configclj

(connect-config config)
source

create-topicclj

(create-topic {:keys [conn schema]}
              topic
              &
              {:keys [key-type value-type index-key?]
               :as opts
               :or {key-type :bytea value-type :bytea index-key? false}})
source

default-subscription-groupclj

source

delete-topicclj

(delete-topic {:keys [conn schema]} topic)
source

deserializer-xfclj

(deserializer-xf config topic {:keys [deserialize-key deserialize-value]})
source

ensure-schemaclj

(ensure-schema {:keys [conn schema]})
source

ensure-subscriptionclj

(ensure-subscription {:keys [conn schema]} {:keys [topic group]})
source

ensure-topicclj

(ensure-topic {:keys [conn] :as config}
              topic-name
              &
              {:keys [key-type value-type]
               :as opts
               :or {key-type :bytea value-type :bytea}})

Fetch or create a topic. Returns the existing topic if it already exists with the same key-type and value-type. Throws if the topic exists but was created with different column types. Note: opts apply only at creation time and cannot be used to change an existing topic.

Fetch or create a topic. Returns the existing topic if it already exists
with the same key-type and value-type. Throws if the topic exists but was
created with different column types. Note: opts apply only at creation time
and cannot be used to change an existing topic.
sourceraw docstring

fetch-records!clj

(fetch-records! config selection)
source

fetch-records*clj

(fetch-records* {:keys [conn schema] :as config}
                {:keys [topic group commit-mode] :as selection})
source

fetch-topicclj

(fetch-topic config topic-name)
source

insert-recordsclj

(insert-records {:keys [conn conn-map schema] :as cfg}
                topic
                records
                &
                {:keys [serialize-key serialize-value] :as opts})
source

(legal-identifier? s)
source

list-subscriptionsclj

(list-subscriptions {:keys [conn schema]} & [{:keys [topics]}])
source

list-topicsclj

(list-topics {:keys [conn schema]})
source

maybe-fetch-topicclj

(maybe-fetch-topic {:keys [conn schema]} topic-name)
source

normalize-selectionclj

(normalize-selection selection)
source

normalize-topic-nameclj

(normalize-topic-name topic)
source

reset-offset!clj

(reset-offset! {:keys [conn schema]} {:keys [topic group]} cursor)
source

selection-defaultsclj

source

sql-entityclj

(sql-entity x)
source

topic-subscriptionsclj

(topic-subscriptions {:keys [conn] :as config})

Returns all topics with their consumer group subscriptions nested under each topic. Unlike list-subscriptions, every topic appears in the result even if it has no subscribers.

Each entry is a map with:

  • :topic the topic name
  • :subscriptions a vector of subscription maps (empty when no subscribers)

Each subscription map contains the same keys as list-subscriptions (except :topic, which is on the outer map):

  • :group consumer group id
  • :offset last committed eid for this group
  • :topic-eid highest eid available in the topic
  • :lag number of unread records (topic-eid - offset)
  • :updated-at java.time.Instant of the last offset commit (nil if never committed)
  • :timestamp java.time.Instant of the last consumed record (nil if offset is 0)
  • :topic-timestamp java.time.Instant of the latest record in the topic (nil if empty)
  • :timestamp-lag java.time.Duration between subscription and topic timestamps (nil if either is nil)
  • :processing-delay java.time.Duration from publish time to consumer commit for the most recently consumed record (nil if either :updated-at or :timestamp is nil)
Returns all topics with their consumer group subscriptions nested under each
topic. Unlike `list-subscriptions`, every topic appears in the result even if
it has no subscribers.

Each entry is a map with:
  - :topic          the topic name
  - :subscriptions  a vector of subscription maps (empty when no subscribers)

Each subscription map contains the same keys as `list-subscriptions` (except
:topic, which is on the outer map):
  - :group             consumer group id
  - :offset            last committed eid for this group
  - :topic-eid         highest eid available in the topic
  - :lag               number of unread records (topic-eid - offset)
  - :updated-at        java.time.Instant of the last offset commit (nil if never committed)
  - :timestamp         java.time.Instant of the last consumed record (nil if offset is 0)
  - :topic-timestamp   java.time.Instant of the latest record in the topic (nil if empty)
  - :timestamp-lag     java.time.Duration between subscription and topic timestamps (nil if either is nil)
  - :processing-delay  java.time.Duration from publish time to consumer commit for the most
                       recently consumed record (nil if either :updated-at or :timestamp is nil)
sourceraw docstring

topic-table-nameclj

(topic-table-name topic)
source

trigger-function-nameclj

(trigger-function-name schema)
source

trigger-function-templateclj

source

trigger-templateclj

source

trim-topicclj

(trim-topic {:keys [conn schema] :as config}
            topic
            &
            {:keys [before-eid before-timestamp all? ignore-subscriptions?]
             :or {ignore-subscriptions? false}})
source

cljdoc builds & hosts documentation for Clojure/Script libraries